#
# spec file for package maven-filtering
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-filtering
Version:        3.3.2
Release:        150200.3.7.2
Summary:        Shared component providing resource filtering
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/%{name}/index.html
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  apache-commons-lang3
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  plexus-build-api0
BuildRequires:  plexus-interpolation
BuildRequires:  plexus-utils
BuildRequires:  sisu-inject
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
These Plexus components have been built from the filtering process/code in
Maven Resources Plugin. The goal is to provide a shared component for all
plugins that needs to filter resources.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%pom_xpath_remove pom:project/pom:parent/pom:relativePath

%build
mkdir -p lib
build-jar-repository -s lib \
    atinject \
    commons-io \
    commons-lang3 \
    maven/maven-core \
    maven/maven-model \
    maven/maven-settings \
    org.eclipse.sisu.inject \
    plexus/utils \
    plexus/interpolation \
    plexus/plexus-build-api0 \
    slf4j/api

%{ant} \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Wed May  1 2024 fstrba@suse.com
- Build against the plexus-build-api0 package containing sonatype
  plexus build api
* Tue Apr  2 2024 fstrba@suse.com
- Upgrade to version 3.3.2
  * Changes
    + pick correct hamcrest dependency
    + Prefer commons lang to plexus utils
    + MSHARED-1214: move tag back to HEAD
    + MSHARED-1216: Use caching output stream
    + Bump org.codehaus.plexus:plexus-utils from 3.0.16 to 3.0.24
    in /src/test/resources
    + Fix typos and grammar
    + Fix 'licenced' typo in PR template
    + refactor IncrementalResourceFilteringTest
    + MSHARED-1340: Require Maven 3.6.3+
    + Bump commons-io:commons-io from 2.11.0 to 2.15.1
    + Bump org.apache.commons:commons-lang3 from 3.12.0 to 3.14.0
    + MSHARED-1339: Bump
    org.apache.maven.shared:maven-shared-components from 39 to 41
    + MSHARED-1290: Fix PropertyUtils cycle detection results in
    false positives
    + MSHARED-1285: use an up-to-date scanner instead the newscanner
    + Bump org.codehaus.plexus:plexus-testing from 1.2.0 to 1.3.0
    + Bump org.codehaus.plexus:plexus-interpolation from 1.26
    to 1.27
    + Bump org.codehaus.plexus:plexus-utils from 3.5.1 to 4.0.0
    + Bump release-drafter/release-drafter from 5 to 6
    + Bump org.junit.jupiter:junit-jupiter-api from 5.10.1
    to 5.10.2
    + MSHARED-1351: Fix console message when origin is baseDir
    + MSHARED-1050: Fix ConcurrentModificationException for
    maven-filtering
    + MSHARED-1330: Always overwrite files
* Wed Sep  6 2023 fstrba@suse.com
- Upgrade to version 3.3.1
  * Changes of 3.3.1
    + MSHARED-1175: Copying x resources from rel/path to rel/path
    + MSHARED-1213: Bug: filtering existing but 0 byte file
    + MSHARED-1199: Upgrade parent pom to 39
    + MSHARED-1112: Ignore setting permissions on non existing dest
    files/symlinks
    + MSHARED-1144: remove rendundant error message
  * Changes of 3.3.0
    + fixed cloning of MavenResourcesExecution's instances using
    copyOf() method
    + MRESOURCES-258: Copying and filtering logic is delegated to
    FileUtils
    + replace deprecated methods
    + replace deprecated code in favor of Java 7 core and apache
    commons libraries
    declare dependencies
    + MSHARED-1080: Parent POM 36, Java8, drop legacy.
* Thu Apr 28 2022 fstrba@suse.com
- Upgrade to version 3.2.0
  * Bug
    + [MSHARED-417] - Infinite loop when loading self-referencing
    properties
    + [MSHARED-599] - Escaping the escape string produces incorrect
    output.
    + [MSHARED-829] - MavenResourcesExecution.copyOf() returns
    newinstance without properties set
  * New Feature
    + [MSHARED-934] - Allow using a different encoding when
    filtering properties files
  * Improvement
    + [MSHARED-646] - Removed prerequisites for none maven-plugin
    project
    + [MSHARED-664] - Add ico files to default non-filtered
    extensions
    + [MSHARED-830] - Require Java 7
    + [MSHARED-879] - make build Reproducible
    + [MSHARED-884] - Only overwrite filtered resources when
    contents differ
    + [MSHARED-946] - Update to maven-shared-utils 3.3.3
  * Dependency upgrade
    + [MSHARED-575] - Upgrade maven-shared-utils to 3.1.0
    + [MSHARED-600] - Upgrade of plexus-interpolation to 1.24.
    + [MSHARED-645] - Upgrade to maven-shared-utils 3.2.0
    + [MSHARED-667] - plexus-utils 3.0.24 to 3.1.0
    + [MSHARED-711] - Upgrade parent to 31
    + [MSHARED-712] - Upgrade maven-surefire/failsafe-plugin
    2.21.0 for JDK 10
    + [MSHARED-755] - Upgrade parent to version 32.
    + [MSHARED-756] - Upgrade plexus-interpolation to 1.25
    + [MSHARED-757] - Upgrade maven-shared-utils to 3.2.1
    + [MSHARED-758] - Upgrade JUnit to 4.12
    + [MSHARED-789] - Upgrade maven-shared-components parent
    to 33
    + [MSHARED-790] - Upgrade plexus-utils 3.1.1
    + [MSHARED-809] - Upgrade plexus-utils 3.2.0
  * needed by maven-resources-plugin 3.2.0
* Sun Mar 20 2022 fstrba@suse.com
- Build with source and target levels 8
* Tue May 11 2021 fstrba@suse.com
- Do not build against legacy guava20 any more
* Mon Mar 25 2019 fstrba@suse.com
- Initial packaging of maven-filtering 3.1.1
- Generate and customize the ant build.xml file
